pub struct PDataReader<'a, R> { /* private fields */ }Expand description
A P-Data value reader.
This exposes an API which provides a byte stream of data by iteratively collecting Data messages from another node. Using this as a standard reader will provide all incoming bytes, even if they reside in separate PDUs, until the last message is received.
Example
Use an association’s receive_pdata method
to create a new P-Data value reader.
// expecting a DICOM object which may be split into multiple PDUs,
let mut pdata = association.receive_pdata();
let all_pdata_bytes = {
let mut v = Vec::new();
pdata.read_to_end(&mut v)?;
v
};Implementations
Sourceimpl<'a, R> PDataReader<'a, R>
impl<'a, R> PDataReader<'a, R>
pub fn new(stream: R, max_data_length: u32, remaining: &'a mut BytesMut) -> Self
Sourcepub fn stop_receiving(&mut self) -> Result<()>
pub fn stop_receiving(&mut self) -> Result<()>
Declare no intention to read more PDUs from the remote node.
Attempting to read more bytes will only consume the inner buffer and not result in more PDUs being received.