pub struct PresentationContextNegotiated {
pub id: u8,
pub reason: PresentationContextResultReason,
pub transfer_syntax: String,
pub abstract_syntax: String,
}Expand description
Result of the presentation context negotiation, including the abstract syntax that corresponds to each presentation context.
Fields
id: u8reason: PresentationContextResultReasontransfer_syntax: Stringabstract_syntax: StringTrait Implementations
Sourceimpl Clone for PresentationContextNegotiated
impl Clone for PresentationContextNegotiated
Sourcefn clone(&self) -> PresentationContextNegotiated
fn clone(&self) -> PresentationContextNegotiated
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Hash for PresentationContextNegotiated
impl Hash for PresentationContextNegotiated
Sourceimpl PartialEq for PresentationContextNegotiated
impl PartialEq for PresentationContextNegotiated
Sourcefn eq(&self, other: &PresentationContextNegotiated) -> bool
fn eq(&self, other: &PresentationContextNegotiated) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PresentationContextNegotiated
impl PartialOrd for PresentationContextNegotiated
impl Eq for PresentationContextNegotiated
impl StructuralPartialEq for PresentationContextNegotiated