pub struct ServerAssociation<S> { /* private fields */ }Expand description
A DICOM upper level association from the perspective of an accepting application entity.
The most common operations of an established association are
send
and receive.
Sending large P-Data fragments may be easier through the P-Data sender
abstraction (see send_pdata).
When the value falls out of scope, the program will shut down the underlying TCP connection.
Implementations
Sourceimpl<S> ServerAssociation<S>
impl<S> ServerAssociation<S>
Sourcepub fn presentation_contexts(&self) -> &[PresentationContextNegotiated]
pub fn presentation_contexts(&self) -> &[PresentationContextNegotiated]
Obtain a view of the negotiated presentation contexts.
Sourcepub fn acceptor_max_pdu_length(&self) -> u32
pub fn acceptor_max_pdu_length(&self) -> u32
Retrieve the maximum PDU length that the association acceptor is expecting to receive.
Sourcepub fn requestor_max_pdu_length(&self) -> u32
pub fn requestor_max_pdu_length(&self) -> u32
Retrieve the maximum PDU length that the association requestor is expecting to receive.
Sourcepub fn client_ae_title(&self) -> &str
👎Deprecated since 0.9.1: Call peer_ae_title from trait Association
pub fn client_ae_title(&self) -> &str
peer_ae_title from trait AssociationObtain the remote DICOM node’s application entity title.
Sourceimpl<S> ServerAssociation<S>
impl<S> ServerAssociation<S>
Sourcepub fn send(&mut self, msg: &Pdu) -> Result<(), Error>
pub fn send(&mut self, msg: &Pdu) -> Result<(), Error>
Send a PDU message to the other intervenient.
Sourcepub fn receive(&mut self) -> Result<Pdu, Error>
pub fn receive(&mut self) -> Result<Pdu, Error>
Read a PDU message from the other intervenient.
Sourcepub fn abort(self) -> Result<(), Error>
pub fn abort(self) -> Result<(), Error>
Send a provider initiated abort message and shut down the TCP connection, terminating the association.
Sourcepub fn send_pdata(&mut self, presentation_context_id: u8) -> PDataWriter<&mut S> ⓘ
pub fn send_pdata(&mut self, presentation_context_id: u8) -> PDataWriter<&mut S> ⓘ
Prepare a P-Data writer for sending one or more data item PDUs.
Returns a writer which automatically splits the inner data into separate PDUs if necessary.
Sourcepub fn receive_pdata(&mut self) -> PDataReader<'_, &mut S> ⓘ
pub fn receive_pdata(&mut self) -> PDataReader<'_, &mut S> ⓘ
Prepare a P-Data reader for receiving one or more data item PDUs.
Returns a reader which automatically receives more data PDUs once the bytes collected are consumed.
Sourcepub fn inner_stream(&mut self) -> &mut S
pub fn inner_stream(&mut self) -> &mut S
Obtain access to the inner stream connected to the association acceptor.
This can be used to send the PDU in semantic fragments of the message, thus using less memory.
Note: reading and writing should be done with care
to avoid inconsistencies in the association state.
Do not call send and receive while not in a PDU boundary.