pub trait Association {
// Required methods
fn peer_ae_title(&self) -> &str;
fn acceptor_max_pdu_length(&self) -> u32;
fn requestor_max_pdu_length(&self) -> u32;
fn local_max_pdu_length(&self) -> u32;
fn peer_max_pdu_length(&self) -> u32;
fn presentation_contexts(&self) -> &[PresentationContextNegotiated];
fn user_variables(&self) -> &[UserVariableItem];
}Expand description
Trait that represents common properties of an association
Required Methods
Sourcefn peer_ae_title(&self) -> &str
fn peer_ae_title(&self) -> &str
Obtain the remote DICOM node’s application entity title.
Sourcefn acceptor_max_pdu_length(&self) -> u32
fn acceptor_max_pdu_length(&self) -> u32
Retrieve the maximum PDU length admitted by the association acceptor.
Sourcefn requestor_max_pdu_length(&self) -> u32
fn requestor_max_pdu_length(&self) -> u32
Retrieve the maximum PDU length admitted by the association requestor.
Sourcefn local_max_pdu_length(&self) -> u32
fn local_max_pdu_length(&self) -> u32
Retrieve the maximum PDU length that this application entity is expecting to receive. That’s the same as acceptor_max_pdu_length() for server objects, and as requestor_max_pdu_length() for client objects.
The current implementation is not required to fail and/or abort the association if a larger PDU is received.
Sourcefn peer_max_pdu_length(&self) -> u32
fn peer_max_pdu_length(&self) -> u32
Retrieve the maximum PDU length admitted by the peer. That’s the same as requestor_max_pdu_length() for server objects, and as acceptor_max_pdu_length() for client objects.
Sourcefn presentation_contexts(&self) -> &[PresentationContextNegotiated]
fn presentation_contexts(&self) -> &[PresentationContextNegotiated]
Obtain a view of the negotiated presentation contexts.
Sourcefn user_variables(&self) -> &[UserVariableItem]
fn user_variables(&self) -> &[UserVariableItem]
Retrieve the user variables that were taken from the server.
It usually contains the maximum PDU length, the implementation class UID, and the implementation version name.